Learn R Programming

HybridMTest (version 1.16.0)

HybridMTest-package: A powerful tool in gene expression hypothesis testing.

Description

This package enables users to generalize the assumption adequacy averaging (AAA) procedure proposed by Pounds and Rai (2009). AAA uses empirical Bayes methodology (Efron et al 2001) to simultaneously evaluate assumptions for each hypothesis test, select the best hypothesis testing procedure for each hypothesis test, and adjust for multiple testing.

Arguments

Details

Package:
HybridMTest
Type:
Package
Version:
1.0
Date:
2010-07-24
License:
GPL (>=2)
LazyLoad:
yes
The main function is hybrid.test. The users may use existing row.test functions (such as row.T.test) or utilize their own row.test functions with similar input and output structures.

References

Pounds SB, Rai SN. (2009) Assumption Adequacy Averaging as a Concept for Developing More Robust Methods for Differential Gene Expression Analysis. Computational Statistics and Data Analysis, 53: 1604-1612 .

B. Efron, R. Tibshirani, J.D. Storey and V. Tusher, Empirical Bayes analysis of a microarray experiment. Journal of American Statistical Association, 96 (2001), pp. 1151-1160.

Examples

Run this code

####################Correlation Data##############
# load data
data(correlation.data)
# Read the expression values  
Y<-exprs(correlation.data)
head(Y)
# Read the phenotype
x<-pData(correlation.data)
####################Three group comparison Data####
# load data
data(GroupComp.data)
# Read the expression values   
brain.express.set <- exprs(GroupComp.data)
head(brain.express.set)
# Read the phenotype
brain.pheno.data <- pData(GroupComp.data)

Run the code above in your browser using DataLab