Learn R Programming

HybridMTest (version 1.16.0)

row.kruskal.wallis: Apply the Kruskal-Wallis test many times

Description

For each row of Y, use the Kruskal-Wallis test to compare medians across groups defined in grplbl

Usage

row.kruskal.wallis(Y, grplbl)

Arguments

Y
data matrix with variables in rows and observations (subjects) in columns
grplbl
vector of group labels

Value

  • A data.frame with three columns
  • stata vector with the test-statistic for each row of Y
  • pvala vector with the p-value for each row of Y
  • ebpa vector with the empirical Bayes probability of equal medians for each row of Y

Details

The alternative hypothesis is that, for each gene, there are at least two groups of different median. The null hypothesis is that all groups have the same median for each gene studied.

References

Kruskal, W.H. and W.A. Wallis (1952) Use of ranks in one-criterion variance analysis. J. Amer. Stat. Assoc. 47:583-621.

Examples

Run this code
####################Three group comparison###################
# load data
data(GroupComp.data)
# Read the expression values   
brain.express.set <- exprs(GroupComp.data)
head(brain.express.set)
# Read the phenotype
brain.pheno.data <- pData(GroupComp.data)
brain.pheno.data[,1] 
row.kruskal.wallis(brain.express.set,brain.pheno.data[,1])

Run the code above in your browser using DataLab