Learn R Programming

HybridMTest (version 1.16.0)

row.spearman: Compute Spearmans rank-based correlation of many variables with a variable x

Description

For each row of the data matrix Y, compute its Spearman correlation with x.

Usage

row.spearman(Y, x)

Arguments

Y
a data matrix with rows for variables and columns for subjects
x
a vector of the variable to be associated with each row of Y

Value

A data.frame with three components:
stat
a vector with the Spearman correlation for each row of Y
pval
a vector with the p-value for each row of Y
ebp
a vector with the estimated empirical Bayes probability of zero correlation for each row of Y

References

Spearman, C. (1904) The proof and measurement of association between two things. Amer. J. Psychol. 15:72-101.

Examples

Run this code
####################Correlation Study#####################
# load data
data(correlation.data)
# Read the expression values  
Y<-exprs(correlation.data)
# Read the phenotype
x<-pData(correlation.data)
x[,1]
#Spearman Test
row.spearman(Y,x[,1])

Run the code above in your browser using DataLab